@@ -2,7 +2,7 @@
 /** @file Document.cxx
  ** Text document that handles notifications, DBCS, styling, words and end of line.
  **/
-// Copyright 1998-2001 by Neil Hodgson <neilh@scintilla.org>
+// Copyright 1998-2003 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
 #include <stdlib.h>
@@ -19,10 +19,26 @@
 #include "RESearch.h"
 
 // This is ASCII specific but is safe with chars >= 0x80
-inline bool isspacechar(unsigned char ch) {
+static inline bool isspacechar(unsigned char ch) {
 	return (ch == ' ') || ((ch >= 0x09) && (ch <= 0x0d));
 }
 
+static inline bool IsPunctuation(char ch) {
+	return isascii(ch) && ispunct(ch);
+}
+
+static inline bool IsADigit(char ch) {
+	return isascii(ch) && isdigit(ch);
+}
+
+static inline bool IsLowerCase(char ch) {
+	return isascii(ch) && islower(ch);
+}
+
+static inline bool IsUpperCase(char ch) {
+	return isascii(ch) && isupper(ch);
+}
+
 Document::Document() {
 	refCount = 0;
 #ifdef unix
@@ -34,8 +50,9 @@ Document::Document() {
 	stylingBits = 5;
 	stylingBitsMask = 0x1F;
 	stylingMask = 0;
-	SetWordChars(0);
+	SetDefaultCharClasses();
 	endStyled = 0;
+	styleClock = 0;
 	enteredCount = 0;
 	enteredReadOnlyCount = 0;
 	tabInChars = 8;
@@ -217,32 +234,12 @@ bool Document::IsCrLf(int pos) {
 	return (cb.CharAt(pos) == '\r') && (cb.CharAt(pos + 1) == '\n');
 }
 
-bool Document::IsDBCS(int pos) {
-	if (dbcsCodePage) {
-		if (SC_CP_UTF8 == dbcsCodePage) {
-			unsigned char ch = static_cast<unsigned char>(cb.CharAt(pos));
-			return ch >= 0x80;
-		} else {
-			// Anchor DBCS calculations at start of line because start of line can
-			// not be a DBCS trail byte.
-			int startLine = pos;
-			while (startLine > 0 && cb.CharAt(startLine) != '\r' && cb.CharAt(startLine) != '\n')
-				startLine--;
-			while (startLine <= pos) {
-				if (Platform::IsDBCSLeadByte(dbcsCodePage, cb.CharAt(startLine))) {
-					startLine++;
-					if (startLine >= pos)
-						return true;
-				}
-				startLine++;
-			}
-		}
-	}
-	return false;
-}
+static const int maxBytesInDBCSCharacter=5;
 
 int Document::LenChar(int pos) {
-	if (IsCrLf(pos)) {
+	if (pos < 0) {
+		return 1;
+	} else if (IsCrLf(pos)) {
 		return 2;
 	} else if (SC_CP_UTF8 == dbcsCodePage) {
 		unsigned char ch = static_cast<unsigned char>(cb.CharAt(pos));
@@ -256,13 +253,19 @@ int Document::LenChar(int pos) {
 			return lengthDoc -pos;
 		else
 			return len;
-	} else if (IsDBCS(pos)) {
-		return 2;
+	} else if (dbcsCodePage) {
+		char mbstr[maxBytesInDBCSCharacter+1];
+		int i;
+		for (i=0; i<Platform::DBCSCharMaxLength(); i++) {
+			mbstr[i] = cb.CharAt(pos+i);
+		}
+		mbstr[i] = '\0';
+		return Platform::DBCSCharLength(dbcsCodePage, mbstr);
 	} else {
 		return 1;
 	}
 }
-
+#include <assert.h>
 // Normalise a position so that it is not halfway through a two byte character.
 // This can occur in two situations -
 // When lines are terminated with \r\n pairs which should be treated as one character.
@@ -270,17 +273,11 @@ int Document::LenChar(int pos) {
 // If moving, move the position in the indicated direction.
 int Document::MovePositionOutsideChar(int pos, int moveDir, bool checkLineEnd) {
 	//Platform::DebugPrintf("NoCRLF %d %d\n", pos, moveDir);
-	// If out of range, just return value - should be fixed up after
-	if (pos < 0)
-		return pos;
-	if (pos > Length())
-		return pos;
-
-	// Position 0 and Length() can not be between any two characters
-	if (pos == 0)
-		return pos;
-	if (pos == Length())
-		return pos;
+	// If out of range, just return minimum/maximum value.
+	if (pos <= 0)
+		return 0;
+	if (pos >= Length())
+		return Length();
 
 	// assert pos > 0 && pos < Length()
 	if (checkLineEnd && IsCrLf(pos - 1)) {
@@ -306,27 +303,26 @@ int Document::MovePositionOutsideChar(int pos, int moveDir, bool checkLineEnd) {
 		} else {
 			// Anchor DBCS calculations at start of line because start of line can
 			// not be a DBCS trail byte.
-			int startLine = pos;
-			while (startLine > 0 && cb.CharAt(startLine) != '\r' && cb.CharAt(startLine) != '\n')
-				startLine--;
-			bool atLeadByte = false;
-			while (startLine < pos) {
-				if (atLeadByte)
-					atLeadByte = false;
-				else if (Platform::IsDBCSLeadByte(dbcsCodePage, cb.CharAt(startLine)))
-					atLeadByte = true;
-				else
-					atLeadByte = false;
-				startLine++;
-			}
+			int posCheck = LineStart(LineFromPosition(pos));
+			while (posCheck < pos) {
+				char mbstr[maxBytesInDBCSCharacter+1];
+				int i;
+				for(i=0;i<Platform::DBCSCharMaxLength();i++) {
+					mbstr[i] = cb.CharAt(posCheck+i);
+				}
+				mbstr[i] = '\0';
 
-
-			if (atLeadByte) {
-				// Position is between a lead byte and a trail byte
-				if (moveDir > 0)
-					return pos + 1;
-				else
-					return pos - 1;
+				int mbsize = Platform::DBCSCharLength(dbcsCodePage, mbstr);
+				if (posCheck + mbsize == pos) {
+					return pos;
+				} else if (posCheck + mbsize > pos) {
+					if (moveDir > 0) {
+						return posCheck + mbsize;
+					} else {
+						return posCheck;
+					}
+				}
+				posCheck += mbsize;
 			}
 		}
 	}
@@ -343,17 +339,19 @@ void Document::ModifiedAt(int pos) {
 // SetStyleAt does not change the persistent state of a document
 
 // Unlike Undo, Redo, and InsertStyledString, the pos argument is a cell number not a char number
-void Document::DeleteChars(int pos, int len) {
+bool Document::DeleteChars(int pos, int len) {
 	if (len == 0)
-		return;
+		return false;
 	if ((pos + len) > Length())
-		return;
+		return false;
 	if (cb.IsReadOnly() && enteredReadOnlyCount == 0) {
 		enteredReadOnlyCount++;
 		NotifyModifyAttempt();
 		enteredReadOnlyCount--;
 	}
-	if (enteredCount == 0) {
+	if (enteredCount != 0) {
+		return false;
+	} else {
 		enteredCount++;
 		if (!cb.IsReadOnly()) {
 			NotifyModified(
@@ -378,22 +376,25 @@ void Document::DeleteChars(int pos, int len) {
 		}
 		enteredCount--;
 	}
+	return !cb.IsReadOnly();
 }
 
-void Document::InsertStyledString(int position, char *s, int insertLength) {
+bool Document::InsertStyledString(int position, char *s, int insertLength) {
 	if (cb.IsReadOnly() && enteredReadOnlyCount == 0) {
 		enteredReadOnlyCount++;
 		NotifyModifyAttempt();
 		enteredReadOnlyCount--;
 	}
-	if (enteredCount == 0) {
+	if (enteredCount != 0) {
+		return false;
+	} else {
 		enteredCount++;
 		if (!cb.IsReadOnly()) {
 			NotifyModified(
 			    DocModification(
 			        SC_MOD_BEFOREINSERT | SC_PERFORMED_USER,
 			        position / 2, insertLength / 2,
-			        0, 0));
+			        0, s));
 			int prevLinesTotal = LinesTotal();
 			bool startSavePoint = cb.IsSavePoint();
 			const char *text = cb.InsertString(position, s, insertLength);
@@ -408,6 +409,7 @@ void Document::InsertStyledString(int position, char *s, int insertLength) {
 		}
 		enteredCount--;
 	}
+	return !cb.IsReadOnly();
 }
 
 int Document::Undo() {
@@ -496,29 +498,32 @@ int Document::Redo() {
 	return newPos;
 }
 
-void Document::InsertChar(int pos, char ch) {
+bool Document::InsertChar(int pos, char ch) {
 	char chs[2];
 	chs[0] = ch;
 	chs[1] = 0;
-	InsertStyledString(pos*2, chs, 2);
+	return InsertStyledString(pos*2, chs, 2);
 }
 
 // Insert a null terminated string
-void Document::InsertString(int position, const char *s) {
-	InsertString(position, s, strlen(s));
+bool Document::InsertString(int position, const char *s) {
+	return InsertString(position, s, strlen(s));
 }
 
 // Insert a string with a length
-void Document::InsertString(int position, const char *s, int insertLength) {
+bool Document::InsertString(int position, const char *s, size_t insertLength) {
+	bool changed = false;
 	char *sWithStyle = new char[insertLength * 2];
 	if (sWithStyle) {
-		for (int i = 0; i < insertLength; i++) {
+		for (size_t i = 0; i < insertLength; i++) {
 			sWithStyle[i*2] = s[i];
 			sWithStyle[i*2 + 1] = 0;
 		}
-		InsertStyledString(position*2, sWithStyle, insertLength*2);
+		changed = InsertStyledString(position*2, sWithStyle,
+			static_cast<int>(insertLength*2));
 		delete []sWithStyle;
 	}
+	return changed;
 }
 
 void Document::ChangeChar(int pos, char ch) {
@@ -530,22 +535,16 @@ void Document::DelChar(int pos) {
 	DeleteChars(pos, LenChar(pos));
 }
 
-int Document::DelCharBack(int pos) {
+void Document::DelCharBack(int pos) {
 	if (pos <= 0) {
-		return pos;
+		return;
 	} else if (IsCrLf(pos - 2)) {
 		DeleteChars(pos - 2, 2);
-		return pos - 2;
-	} else if (SC_CP_UTF8 == dbcsCodePage) {
+	} else if (dbcsCodePage) {
 		int startChar = MovePositionOutsideChar(pos - 1, -1, false);
 		DeleteChars(startChar, pos - startChar);
-		return startChar;
-	} else if (IsDBCS(pos - 1)) {
-		DeleteChars(pos - 2, 2);
-		return pos - 2;
 	} else {
 		DeleteChars(pos - 1, 1);
-		return pos - 1;
 	}
 }
 
@@ -712,6 +711,33 @@ void Document::ConvertLineEnds(int eolModeSet) {
 	EndUndoAction();
 }
 
+int Document::ParaDown(int pos) {
+	int line = LineFromPosition(pos);
+	while (line < LinesTotal() && LineStart(line) != LineEnd(line)) { // skip non-empty lines
+		line++;
+	}
+	while (line < LinesTotal() && LineStart(line) == LineEnd(line)) { // skip empty lines
+		line++;
+	}
+	if (line < LinesTotal())
+		return LineStart(line);
+	else // end of a document
+		return LineEnd(line-1);
+}
+
+int Document::ParaUp(int pos) {
+	int line = LineFromPosition(pos);
+	line--;
+	while (line >= 0 && LineStart(line) == LineEnd(line)) { // skip empty lines
+		line--;
+	}
+	while (line >= 0 && LineStart(line) != LineEnd(line)) { // skip non-empty lines
+		line--;
+	}
+	line++;
+	return LineStart(line);
+}
+
 Document::charClassification Document::WordCharClass(unsigned char ch) {
 	if ((SC_CP_UTF8 == dbcsCodePage) && (ch >= 0x80))
 		return ccWord;
@@ -722,21 +748,24 @@ Document::charClassification Document::WordCharClass(unsigned char ch) {
  * Used by commmands that want to select whole words.
  * Finds the start of word at pos when delta < 0 or the end of the word when delta >= 0.
  */
-int Document::ExtendWordSelect(int pos, int delta) {
+int Document::ExtendWordSelect(int pos, int delta, bool onlyWordCharacters) {
+	charClassification ccStart = ccWord;
 	if (delta < 0) {
-		charClassification ccStart = WordCharClass(cb.CharAt(pos-1));
+		if (!onlyWordCharacters)
+			ccStart = WordCharClass(cb.CharAt(pos-1));
 		while (pos > 0 && (WordCharClass(cb.CharAt(pos - 1)) == ccStart))
 			pos--;
 	} else {
-		charClassification ccStart = WordCharClass(cb.CharAt(pos));
+		if (!onlyWordCharacters)
+			ccStart = WordCharClass(cb.CharAt(pos));
 		while (pos < (Length()) && (WordCharClass(cb.CharAt(pos)) == ccStart))
 			pos++;
 	}
-	return pos;
+	return MovePositionOutsideChar(pos, delta);
 }
 
 /**
- * Find the start of the next word in either a forward (delta >= 0) or backwards direction 
+ * Find the start of the next word in either a forward (delta >= 0) or backwards direction
  * (delta < 0).
  * This is looking for a transition between character classes although there is also some
  * additional movement to transit white space.
@@ -762,6 +791,40 @@ int Document::NextWordStart(int pos, int delta) {
 	return pos;
 }
 
+/**
+ * Find the end of the next word in either a forward (delta >= 0) or backwards direction
+ * (delta < 0).
+ * This is looking for a transition between character classes although there is also some
+ * additional movement to transit white space.
+ * Used by cursor movement by word commands.
+ */
+int Document::NextWordEnd(int pos, int delta) {
+	if (delta < 0) {
+		if (pos > 0) {
+			charClassification ccStart = WordCharClass(cb.CharAt(pos-1));
+			if (ccStart != ccSpace) {
+				while (pos > 0 && WordCharClass(cb.CharAt(pos - 1)) == ccStart) {
+					pos--;
+				}
+			}
+			while (pos > 0 && WordCharClass(cb.CharAt(pos - 1)) == ccSpace) {
+				pos--;
+			}
+		}
+	} else {
+		while (pos < Length() && WordCharClass(cb.CharAt(pos)) == ccSpace) {
+			pos++;
+		}
+		if (pos < Length()) {
+			charClassification ccStart = WordCharClass(cb.CharAt(pos));
+			while (pos < Length() && WordCharClass(cb.CharAt(pos)) == ccStart) {
+				pos++;
+			}
+		}
+	}
+	return pos;
+}
+
 /**
  * Check that the character at the given position is a word or punctuation character and that
  * the previous character is of a different character class.
@@ -789,7 +852,7 @@ bool Document::IsWordEndAt(int pos) {
 }
 
 /**
- * Check that the given range is has transitions between character classes at both 
+ * Check that the given range is has transitions between character classes at both
  * ends and where the characters on the inside are word or punctuation characters.
  */
 bool Document::IsWordAt(int start, int end) {
@@ -818,8 +881,9 @@ class DocumentIndexer : public CharacterIndexer {
 	Document *pdoc;
 	int end;
 public:
-DocumentIndexer(Document *pdoc_, int end_) :
-	pdoc(pdoc_), end(end_) {}
+	DocumentIndexer(Document *pdoc_, int end_) :
+		pdoc(pdoc_), end(end_) {
+	}
 
 	virtual char CharAt(int index) {
 		if (index < 0 || index >= end)
@@ -835,7 +899,7 @@ DocumentIndexer(Document *pdoc_, int end_) :
  * Has not been tested with backwards DBCS searches yet.
  */
 long Document::FindText(int minPos, int maxPos, const char *s,
-                        bool caseSensitive, bool word, bool wordStart, bool regExp,
+                        bool caseSensitive, bool word, bool wordStart, bool regExp, bool posix,
                         int *length) {
 	if (regExp) {
 		if (!pre)
@@ -843,22 +907,16 @@ long Document::FindText(int minPos, int maxPos, const char *s,
 		if (!pre)
 			return -1;
 
-		int startPos;
-		int endPos;
+		int increment = (minPos <= maxPos) ? 1 : -1;
 
-		if (minPos <= maxPos) {
-			startPos = minPos;
-			endPos = maxPos;
-		} else {
-			startPos = maxPos;
-			endPos = minPos;
-		}
+		int startPos = minPos;
+		int endPos = maxPos;
 
 		// Range endpoints should not be inside DBCS characters, but just in case, move them.
 		startPos = MovePositionOutsideChar(startPos, 1, false);
 		endPos = MovePositionOutsideChar(endPos, 1, false);
 
-		const char *errmsg = pre->Compile(s, *length, caseSensitive);
+		const char *errmsg = pre->Compile(s, *length, caseSensitive, posix);
 		if (errmsg) {
 			return -1;
 		}
@@ -868,7 +926,9 @@ long Document::FindText(int minPos, int maxPos, const char *s,
 		//     Replace: $(\1-\2)
 		int lineRangeStart = LineFromPosition(startPos);
 		int lineRangeEnd = LineFromPosition(endPos);
-		if ((startPos >= LineEnd(lineRangeStart)) && (lineRangeStart < lineRangeEnd)) {
+		if ((increment == 1) &&
+			(startPos >= LineEnd(lineRangeStart)) &&
+			(lineRangeStart < lineRangeEnd)) {
 			// the start position is at end of line or between line end characters.
 			lineRangeStart++;
 			startPos = LineStart(lineRangeStart);
@@ -876,36 +936,54 @@ long Document::FindText(int minPos, int maxPos, const char *s,
 		int pos = -1;
 		int lenRet = 0;
 		char searchEnd = s[*length - 1];
-		if (*length == 1) {
-			// These produce empty selections so nudge them on if needed
-			if (s[0] == '^') {
-				if (startPos == LineStart(lineRangeStart))
-					startPos++;
-			} else if (s[0] == '$') {
-				if ((startPos == LineEnd(lineRangeStart)) && (lineRangeStart < lineRangeEnd))
-					startPos = LineStart(lineRangeStart + 1);
-			}
-			lineRangeStart = LineFromPosition(startPos);
-			lineRangeEnd = LineFromPosition(endPos);
-		}
-		for (int line = lineRangeStart; line <= lineRangeEnd; line++) {
+		int lineRangeBreak = lineRangeEnd + increment;
+		for (int line = lineRangeStart; line != lineRangeBreak; line += increment) {
 			int startOfLine = LineStart(line);
 			int endOfLine = LineEnd(line);
-			if (line == lineRangeStart) {
-				if ((startPos != startOfLine) && (s[0] == '^'))
-					continue;	// Can't match start of line if start position after start of line
-				startOfLine = startPos;
-			}
-			if (line == lineRangeEnd) {
-				if ((endPos != endOfLine) && (searchEnd == '$'))
-					continue;	// Can't match end of line if end position before end of line
-				endOfLine = endPos;
+			if (increment == 1) {
+				if (line == lineRangeStart) {
+					if ((startPos != startOfLine) && (s[0] == '^'))
+						continue;	// Can't match start of line if start position after start of line
+					startOfLine = startPos;
+				}
+				if (line == lineRangeEnd) {
+					if ((endPos != endOfLine) && (searchEnd == '$'))
+						continue;	// Can't match end of line if end position before end of line
+					endOfLine = endPos;
+				}
+			} else {
+				if (line == lineRangeEnd) {
+					if ((endPos != startOfLine) && (s[0] == '^'))
+						continue;	// Can't match start of line if end position after start of line
+					startOfLine = endPos;
+				}
+				if (line == lineRangeStart) {
+					if ((startPos != endOfLine) && (searchEnd == '$'))
+						continue;	// Can't match end of line if start position before end of line
+					endOfLine = startPos+1;
+				}
 			}
+
 			DocumentIndexer di(this, endOfLine);
 			int success = pre->Execute(di, startOfLine, endOfLine);
 			if (success) {
 				pos = pre->bopat[0];
 				lenRet = pre->eopat[0] - pre->bopat[0];
+				if (increment == -1) {
+					// Check for the last match on this line.
+					int repetitions = 1000;	// Break out of infinite loop
+					while (success && (pre->eopat[0] <= (endOfLine+1)) && (repetitions--)) {
+						success = pre->Execute(di, pos+1, endOfLine+1);
+						if (success) {
+							if (pre->eopat[0] <= (minPos+1)) {
+								pos = pre->bopat[0];
+								lenRet = pre->eopat[0] - pre->bopat[0];
+							} else {
+								success = 0;
+							}
+						}
+					}
+				}
 				break;
 			}
 		}
@@ -924,7 +1002,7 @@ long Document::FindText(int minPos, int maxPos, const char *s,
 		// Compute actual search ranges needed
 		int lengthFind = *length;
 		if (lengthFind == -1)
-			lengthFind = strlen(s);
+			lengthFind = static_cast<int>(strlen(s));
 		int endSearch = endPos;
 		if (startPos <= endPos) {
 			endSearch = endPos - lengthFind + 1;
@@ -968,7 +1046,7 @@ long Document::FindText(int minPos, int maxPos, const char *s,
 				}
 			}
 			pos += increment;
-			if (dbcsCodePage) {
+			if (dbcsCodePage && (pos >= 0)) {
 				// Ensure trying to match from start of character
 				pos = MovePositionOutsideChar(pos, increment, false);
 			}
@@ -988,10 +1066,24 @@ const char *Document::SubstituteByPosition(const char *text, int *length) {
 		return 0;
 	unsigned int lenResult = 0;
 	for (int i = 0; i < *length; i++) {
-		if ((text[i] == '\\') && (text[i + 1] >= '1' && text[i + 1] <= '9')) {
-			unsigned int patNum = text[i + 1] - '0';
-			lenResult += pre->eopat[patNum] - pre->bopat[patNum];
-			i++;
+		if (text[i] == '\\') {
+			if (text[i + 1] >= '1' && text[i + 1] <= '9') {
+				unsigned int patNum = text[i + 1] - '0';
+				lenResult += pre->eopat[patNum] - pre->bopat[patNum];
+				i++;
+			} else {
+				switch (text[i + 1]) {
+				case 'a':
+				case 'b':
+				case 'f':
+				case 'n':
+				case 'r':
+				case 't':
+				case 'v':
+					i++;
+				}
+				lenResult++;
+			}
 		} else {
 			lenResult++;
 		}
@@ -1001,13 +1093,43 @@ const char *Document::SubstituteByPosition(const char *text, int *length) {
 		return 0;
 	char *o = substituted;
 	for (int j = 0; j < *length; j++) {
-		if ((text[j] == '\\') && (text[j + 1] >= '1' && text[j + 1] <= '9')) {
-			unsigned int patNum = text[j + 1] - '0';
-			unsigned int len = pre->eopat[patNum] - pre->bopat[patNum];
-			if (pre->pat[patNum])	// Will be null if try for a match that did not occur
-				memcpy(o, pre->pat[patNum], len);
-			o += len;
-			j++;
+		if (text[j] == '\\') {
+			if (text[j + 1] >= '1' && text[j + 1] <= '9') {
+				unsigned int patNum = text[j + 1] - '0';
+				unsigned int len = pre->eopat[patNum] - pre->bopat[patNum];
+				if (pre->pat[patNum])	// Will be null if try for a match that did not occur
+					memcpy(o, pre->pat[patNum], len);
+				o += len;
+				j++;
+			} else {
+				j++;
+				switch (text[j]) {
+				case 'a':
+					*o++ = '\a';
+					break;
+				case 'b':
+					*o++ = '\b';
+					break;
+				case 'f':
+					*o++ = '\f';
+					break;
+				case 'n':
+					*o++ = '\n';
+					break;
+				case 'r':
+					*o++ = '\r';
+					break;
+				case 't':
+					*o++ = '\t';
+					break;
+				case 'v':
+					*o++ = '\v';
+					break;
+				default:
+					*o++ = '\\';
+					j--;
+				}
+			}
 		} else {
 			*o++ = text[j];
 		}
@@ -1023,16 +1145,17 @@ int Document::LinesTotal() {
 
 void Document::ChangeCase(Range r, bool makeUpperCase) {
 	for (int pos = r.start; pos < r.end; pos++) {
-		char ch = CharAt(pos);
-		if (dbcsCodePage && IsDBCS(pos)) {
-			pos += LenChar(pos);
+		int len = LenChar(pos);
+		if (dbcsCodePage && (len > 1)) {
+			pos += len;
 		} else {
+			char ch = CharAt(pos);
 			if (makeUpperCase) {
-				if (islower(ch)) {
+				if (IsLowerCase(ch)) {
 					ChangeChar(pos, static_cast<char>(MakeUpperCase(ch)));
 				}
 			} else {
-				if (isupper(ch)) {
+				if (IsUpperCase(ch)) {
 					ChangeChar(pos, static_cast<char>(MakeLowerCase(ch)));
 				}
 			}
@@ -1040,26 +1163,27 @@ void Document::ChangeCase(Range r, bool makeUpperCase) {
 	}
 }
 
-void Document::SetWordChars(unsigned char *chars) {
-	int ch;
-	for (ch = 0; ch < 256; ch++) {
+void Document::SetDefaultCharClasses() {
+	// Initialize all char classes to default values
+	for (int ch = 0; ch < 256; ch++) {
 		if (ch == '\r' || ch == '\n')
 			charClass[ch] = ccNewLine;
 		else if (ch < 0x20 || ch == ' ')
 			charClass[ch] = ccSpace;
+		else if (ch >= 0x80 || isalnum(ch) || ch == '_')
+			charClass[ch] = ccWord;
 		else
 			charClass[ch] = ccPunctuation;
 	}
+}
+
+void Document::SetCharClasses(unsigned char *chars, charClassification newCharClass) {
+	// Apply the newCharClass to the specifed chars
 	if (chars) {
 		while (*chars) {
-			charClass[*chars] = ccWord;
+			charClass[*chars] = newCharClass;
 			chars++;
 		}
-	} else {
-		for (ch = 0; ch < 256; ch++) {
-			if (ch >= 0x80 || isalnum(ch) || ch == '_') 
-				charClass[ch] = ccWord;
-		}
 	}
 }
 
@@ -1077,9 +1201,12 @@ void Document::StartStyling(int position, char mask) {
 	endStyled = position;
 }
 
-void Document::SetStyleFor(int length, char style) {
-	if (enteredCount == 0) {
+bool Document::SetStyleFor(int length, char style) {
+	if (enteredCount != 0) {
+		return false;
+	} else {
 		enteredCount++;
+		style &= stylingMask;
 		int prevEndStyled = endStyled;
 		if (cb.SetStyleFor(endStyled, length, style, stylingMask)) {
 			DocModification mh(SC_MOD_CHANGESTYLE | SC_PERFORMED_USER,
@@ -1088,32 +1215,46 @@ void Document::SetStyleFor(int length, char style) {
 		}
 		endStyled += length;
 		enteredCount--;
+		return true;
 	}
 }
 
-void Document::SetStyles(int length, char *styles) {
-	if (enteredCount == 0) {
+bool Document::SetStyles(int length, char *styles) {
+	if (enteredCount != 0) {
+		return false;
+	} else {
 		enteredCount++;
 		int prevEndStyled = endStyled;
 		bool didChange = false;
+		int lastChange = 0;
 		for (int iPos = 0; iPos < length; iPos++, endStyled++) {
+			PLATFORM_ASSERT(endStyled < Length());
 			if (cb.SetStyleAt(endStyled, styles[iPos], stylingMask)) {
 				didChange = true;
+				lastChange = iPos;
 			}
 		}
 		if (didChange) {
 			DocModification mh(SC_MOD_CHANGESTYLE | SC_PERFORMED_USER,
-			                   prevEndStyled, endStyled - prevEndStyled);
+			                   prevEndStyled, lastChange);
 			NotifyModified(mh);
 		}
 		enteredCount--;
+		return true;
 	}
 }
 
 bool Document::EnsureStyledTo(int pos) {
-	// Ask the watchers to style, and stop as soon as one responds.
-	for (int i = 0; pos > GetEndStyled() && i < lenWatchers; i++)
-		watchers[i].watcher->NotifyStyleNeeded(this, watchers[i].userData, pos);
+	if (pos > GetEndStyled()) {
+		styleClock++;
+		if (styleClock > 0x100000) {
+			styleClock = 0;
+		}
+		// Ask the watchers to style, and stop as soon as one responds.
+		for (int i = 0; pos > GetEndStyled() && i < lenWatchers; i++) {
+			watchers[i].watcher->NotifyStyleNeeded(this, watchers[i].userData, pos);
+		}
+	}
 	return pos <= GetEndStyled();
 }
 
@@ -1180,7 +1321,7 @@ void Document::NotifyModified(DocModification mh) {
 }
 
 bool Document::IsWordPartSeparator(char ch) {
-	return ispunct(ch) && (WordCharClass(ch) == ccWord);
+	return (WordCharClass(ch) == ccWord) && IsPunctuation(ch);
 }
 
 int Document::WordPartLeft(int pos) {
@@ -1195,31 +1336,38 @@ int Document::WordPartLeft(int pos) {
 		if (pos > 0) {
 			startChar = cb.CharAt(pos);
 			--pos;
-			if (islower(startChar)) {
-				while (pos > 0 && islower(cb.CharAt(pos)))
+			if (IsLowerCase(startChar)) {
+				while (pos > 0 && IsLowerCase(cb.CharAt(pos)))
 					--pos;
-				if (!isupper(cb.CharAt(pos)) && !islower(cb.CharAt(pos)))
+				if (!IsUpperCase(cb.CharAt(pos)) && !IsLowerCase(cb.CharAt(pos)))
 					++pos;
-			} else if (isupper(startChar)) {
-				while (pos > 0 && isupper(cb.CharAt(pos)))
+			} else if (IsUpperCase(startChar)) {
+				while (pos > 0 && IsUpperCase(cb.CharAt(pos)))
 					--pos;
-				if (!isupper(cb.CharAt(pos)))
+				if (!IsUpperCase(cb.CharAt(pos)))
 					++pos;
-			} else if (isdigit(startChar)) {
-				while (pos > 0 && isdigit(cb.CharAt(pos)))
+			} else if (IsADigit(startChar)) {
+				while (pos > 0 && IsADigit(cb.CharAt(pos)))
 					--pos;
-				if (!isdigit(cb.CharAt(pos)))
+				if (!IsADigit(cb.CharAt(pos)))
 					++pos;
-			} else if (ispunct(startChar)) {
-				while (pos > 0 && ispunct(cb.CharAt(pos)))
+			} else if (IsPunctuation(startChar)) {
+				while (pos > 0 && IsPunctuation(cb.CharAt(pos)))
 					--pos;
-				if (!ispunct(cb.CharAt(pos)))
+				if (!IsPunctuation(cb.CharAt(pos)))
 					++pos;
 			} else if (isspacechar(startChar)) {
 				while (pos > 0 && isspacechar(cb.CharAt(pos)))
 					--pos;
 				if (!isspacechar(cb.CharAt(pos)))
 					++pos;
+			} else if (!isascii(startChar)) {
+				while (pos > 0 && !isascii(cb.CharAt(pos)))
+					--pos;
+				if (isascii(cb.CharAt(pos)))
+					++pos;
+			} else {
+				++pos;
 			}
 		}
 	}
@@ -1234,29 +1382,51 @@ int Document::WordPartRight(int pos) {
 			++pos;
 		startChar = cb.CharAt(pos);
 	}
-	if (islower(startChar)) {
-		while (pos < length && islower(cb.CharAt(pos)))
+	if (!isascii(startChar)) {
+		while (pos < length && !isascii(cb.CharAt(pos)))
 			++pos;
-	} else if (isupper(startChar)) {
-		if (islower(cb.CharAt(pos + 1))) {
+	} else if (IsLowerCase(startChar)) {
+		while (pos < length && IsLowerCase(cb.CharAt(pos)))
 			++pos;
-			while (pos < length && islower(cb.CharAt(pos)))
+	} else if (IsUpperCase(startChar)) {
+		if (IsLowerCase(cb.CharAt(pos + 1))) {
+			++pos;
+			while (pos < length && IsLowerCase(cb.CharAt(pos)))
 				++pos;
 		} else {
-			while (pos < length && isupper(cb.CharAt(pos)))
+			while (pos < length && IsUpperCase(cb.CharAt(pos)))
 				++pos;
 		}
-		if (islower(cb.CharAt(pos)) && isupper(cb.CharAt(pos - 1)))
+		if (IsLowerCase(cb.CharAt(pos)) && IsUpperCase(cb.CharAt(pos - 1)))
 			--pos;
-	} else if (isdigit(startChar)) {
-		while (pos < length && isdigit(cb.CharAt(pos)))
+	} else if (IsADigit(startChar)) {
+		while (pos < length && IsADigit(cb.CharAt(pos)))
 			++pos;
-	} else if (ispunct(startChar)) {
-		while (pos < length && ispunct(cb.CharAt(pos)))
+	} else if (IsPunctuation(startChar)) {
+		while (pos < length && IsPunctuation(cb.CharAt(pos)))
 			++pos;
 	} else if (isspacechar(startChar)) {
 		while (pos < length && isspacechar(cb.CharAt(pos)))
 			++pos;
+	} else {
+		++pos;
+	}
+	return pos;
+}
+
+bool IsLineEndChar(char c) {
+	return (c == '\n' || c == '\r');
+}
+
+int Document::ExtendStyleRange(int pos, int delta, bool singleLine) {
+	int sStart = cb.StyleAt(pos);
+	if (delta < 0) {
+		while (pos > 0 && (cb.StyleAt(pos) == sStart) && (!singleLine || !IsLineEndChar(cb.CharAt(pos))) )
+			pos--;
+		pos++;
+	} else {
+		while (pos < (Length()) && (cb.StyleAt(pos) == sStart) && (!singleLine || !IsLineEndChar(cb.CharAt(pos))) )
+			pos++;
 	}
 	return pos;
 }
