@@ -78,6 +78,7 @@ static const char *authors[] = {
 	"Dave Huseby <huseby@shockfusion.com>",
 	"Sebastien Cote <cots01@gel.usherb.ca>",
 	"Stephen Knight <steven.knight@unh.edu>",
+	"James Liggett <jrliggett@cox.net>",
 	NULL
 };
 
@@ -110,7 +111,7 @@ about_box_new ()
 		GList *node;
 		char *line;
 		char *utfline;
-		int count;
+		size_t count;
 		
 		list = NULL;
 		while (!feof(infile) && !ferror (infile))
