@@ -144,6 +144,10 @@ anjuta_new ()
 			on_build_msg_save_ok_clicked,
 			on_build_msg_save_cancel_clicked, NULL
 		};
+		
+		TextEditor *te;
+		GtkTextView *explorer_view;
+		
 		app->size = sizeof(AnjutaApp);
 		app->addIns_list	= NULL ;
 		app->shutdown_in_progress = FALSE;
@@ -250,11 +254,25 @@ anjuta_new ()
 		g_signal_connect (G_OBJECT (app->launcher), "busy",
 						  G_CALLBACK (update_ui_from_launcher), NULL);
 		debugger_init ();
+
+		te = text_editor_new(NULL, NULL, ANJUTA_PREFERENCES (app->preferences), NULL);
+		if (te != NULL)
+		{
+			an_message_manager_set_widget (app->messages, MESSAGE_EXPLORER,
+								   te->widgets.client);
+			app->explorer_view = te;
+		}
+		
 		anjuta_plugins_load();
 		anjuta_tools_load();
 		anjuta_load_yourself (ANJUTA_PREFERENCES (app->preferences)->props);
 		gtk_window_move (GTK_WINDOW (app->widgets.window), app->win_pos_x,
 						 app->win_pos_y);
+		
+	/* If window was maximized on last run, maximize it again */
+	if (app->win_maximized)
+		gtk_window_maximize(GTK_WINDOW (app->widgets.window));
+	
 		gtk_window_set_default_size (GTK_WINDOW (app->widgets.window),
 								     app->win_width, app->win_height);
 		main_toolbar_update ();
@@ -559,6 +577,61 @@ anjuta_goto_file_line_mark (const gchar * fname, glong lineno, gboolean mark)
 	return te ;
 }
 
+gint anjuta_explorer_view_goto_file_line_mark (const gchar * fname, glong lineno, gboolean mark)
+{
+	gchar *fn;
+	TextEditor *te;
+	guint *explorer_height;
+
+	g_return_val_if_fail (fname, NULL);
+	fn = anjuta_get_full_filename (fname);
+	g_return_val_if_fail (fname != NULL, NULL);
+
+	te = app->explorer_view;
+	if (te)
+	{
+		if ((!te->full_filename) || (strcmp(fn, te->full_filename) != 0))
+		{
+			g_free(te->filename);
+			g_free(te->full_filename);
+			te->filename = g_strdup(fname);
+			te->full_filename = g_strdup(fn);
+			text_editor_load_file(te);
+		}
+		if (lineno >= 0)
+		{
+			gint selpos;
+			text_editor_goto_line (te, lineno, mark, FALSE);
+				te->current_line = lineno;
+			scintilla_send_message (SCINTILLA (te->widgets.editor), 
+					SCI_MARKERDELETEALL,	2, 0); /* TEXT_EDITOR_LINEMARKER =2 */
+			text_editor_set_marker (te, lineno, 2);
+		
+			selpos = scintilla_send_message(SCINTILLA (te->widgets.editor),
+											SCI_POSITIONFROMLINE,
+										linenum_text_editor_to_scintilla (lineno), 0);
+			scintilla_send_message (SCINTILLA (te->widgets.editor),
+									SCI_SETSELECTIONSTART, selpos, 0);
+			scintilla_send_message (SCINTILLA (te->widgets.editor),
+									SCI_SETSELECTIONEND, selpos, 0);
+			
+			explorer_height = scintilla_send_message (SCINTILLA (te->widgets.editor),
+									SCI_TEXTHEIGHT, 0, 0);
+			/* This ensures that we have arround 1 lines visible upon the mark, 
+			    and locat to to top of the explorer view */
+			scintilla_send_message (SCINTILLA (te->widgets.editor), SCI_GOTOLINE, 
+				linenum_text_editor_to_scintilla (lineno)+ explorer_height - 1, 0);
+			scintilla_send_message (SCINTILLA (te->widgets.editor), SCI_GOTOLINE, 
+				linenum_text_editor_to_scintilla (lineno), 0);
+			/* Since we cannot save this window we make it read-only */
+			scintilla_send_message (SCINTILLA (te->widgets.editor), SCI_SETREADONLY, 
+				TRUE, 0);
+		}
+	}
+	g_free (fn);
+	return 0;
+}
+
 const GList *anjuta_get_tag_list(TextEditor *te, guint tag_types)
 {
 	static GList *tag_names = NULL;
@@ -939,6 +1012,7 @@ anjuta_save_yourself (FILE * stream)
 	fprintf (stream,
 		 _("# * DO NOT EDIT OR RENAME THIS FILE ** Generated by Anjuta **\n"));
 	fprintf (stream, "anjuta.version=%s\n", VERSION);
+	fprintf (stream, "anjuta.win.maximized=%d\n", app->win_maximized);
 	fprintf (stream, "anjuta.win.pos.x=%d\n", app->win_pos_x);
 	fprintf (stream, "anjuta.win.pos.y=%d\n", app->win_pos_y);
 	fprintf (stream, "anjuta.win.width=%d\n", app->win_width);
@@ -1063,7 +1137,9 @@ anjuta_save_yourself (FILE * stream)
 gboolean anjuta_load_yourself (PropsID pr)
 {
 	gint length;
-
+	
+	app->win_maximized = prop_get_int(pr, "anjuta.win.maximized", 
+									  app->win_maximized);
 	app->win_pos_x = prop_get_int (pr, "anjuta.win.pos.x", app->win_pos_x);
 	app->win_pos_y = prop_get_int (pr, "anjuta.win.pos.y", app->win_pos_y);
 	app->win_width = prop_get_int (pr, "anjuta.win.width", app->win_width);
