@@ -97,7 +97,7 @@ struct _AnjutaApp
 	AnjutaPreferences *preferences;
 	CompilerOptions *compiler_options;
 	SrcPaths *src_paths;
-	TextEditor *current_text_editor;
+	TextEditor *current_text_editor, *explorer_view;
 	AnjutaDirs *dirs;
 	Executer *executer;
 	Configurer *configurer;
@@ -116,6 +116,7 @@ struct _AnjutaApp
 	gint hpaned_width;
 	gint vpaned_height;
 	gint win_pos_x, win_pos_y, win_width, win_height;
+	gboolean win_maximized;
 	gboolean auto_gtk_update;
 
 	GnomeAppProgressKey progress_key;
@@ -193,6 +194,8 @@ gchar *anjuta_get_current_selection (void);
 TextEditor*  anjuta_goto_file_line (const gchar * fname, glong lineno);
 TextEditor*  anjuta_goto_file_line_mark (const gchar * fname,
 										 glong lineno, gboolean mark);
+gint anjuta_explorer_view_goto_file_line_mark (const gchar * fname, 
+										glong lineno, gboolean mark);
 gboolean anjuta_goto_local_tag(TextEditor *te, const char *qual_name);
 void anjuta_goto_tag(const char *symbol, TextEditor *te,
 					 gboolean prefer_definition);
@@ -303,6 +306,11 @@ gint on_anjuta_window_key_press_event (GtkWidget   *widget,
 gint on_anjuta_window_key_release_event (GtkWidget   *widget,
 										 GdkEventKey *event,
 										 gpointer     user_data);
+										 
+gint on_anjuta_window_state (GtkWidget	*widget,
+							 GdkEventWindowState *event,
+							 gpointer user_data);
+							 
                
 void on_open_filesel_ok_clicked (GtkDialog *dlg, gpointer data);
 void on_open_filesel_cancel_clicked (GtkDialog *dlg, gpointer data);
