@@ -104,6 +104,7 @@ gint on_anjuta_delete (GtkWidget * w, GdkEvent * event, gpointer data)
 	gint max_recent_files, max_recent_prjs;
 	
 	if (!app) return TRUE;
+	gnome_accelerators_sync();
 	file_not_saved = FALSE;
 	p = app->project_dbase;
 	
@@ -261,6 +262,21 @@ on_anjuta_window_focus_in_event (GtkWidget * widget,
 	return FALSE;
 }
 
+gint
+on_anjuta_window_state (GtkWidget	*widget,GdkEventWindowState *event,
+						gpointer user_data)
+{
+	/* If window has been maximized, set app->win_maximized accordingly */
+	
+	if ((event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED))
+		app->win_maximized = TRUE;
+	else
+		app->win_maximized = FALSE;
+	
+	return TRUE;
+}
+	
+
 enum {
 	m___ = 0,
 	mS__ = GDK_SHIFT_MASK,
