@@ -280,10 +280,10 @@ char* default_settings=
 "command.terminal=gnome-terminal --command=\"sh -c \\\"$(anjuta.current.command); read x\\\"\"\n"
 "anjuta.compiler.flags=-O -g\n"
 "anjuta.linker.flags=\n"
-"command.view.file.$(file.patterns.icon)=gnome-iconedit $(current.file.name.ext)\n"
+"command.view.file.$(file.patterns.icon)=gimp $(current.file.name.ext)\n"
 "command.view.file.$(file.patterns.image)=gimp $(current.file.name.ext)\n"
-"command.view.file.$(file.patterns.html)=gnome-help-browser file:$(current.full.filename.ext)\n"
-"command.open.file.$(file.patterns.icon)=gnome-iconedit $(current.file.name.ext)\n"
+"command.view.file.$(file.patterns.html)=yelp file:$(current.full.filename.ext)\n"
+"command.open.file.$(file.patterns.icon)=gimp $(current.file.name.ext)\n"
 "command.open.file.$(file.patterns.image)=gimp $(current.file.name.ext)\n"
 "command.open.file.$(file.patterns.html)=\n"
 "command.compile.file.$(file.patterns.c)=gcc $(anjuta.compiler.flags) -c $(current.file.name.ext) -o $(current.file.name).o\n"
