@@ -20,7 +20,6 @@
 #ifndef _GNOME_PROJECT_H_
 #define _GNOME_PROJECT_H_
 
-gboolean
-create_new_project (AppWizard * aw);
+gboolean create_new_project (AppWizard *aw);
 
 #endif
