@@ -105,7 +105,8 @@ MessageSubwindow::MessageSubwindow(AnMessageManager* p_amm,
 }
 
 GtkWidget* 
-MessageSubwindow::create_scrolled_window(GtkWidget* widget_in_window)
+MessageSubwindow::create_scrolled_window(GtkWidget* widget_in_window,
+	bool viewport)
 {
 	GtkWidget* scrolled_win = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolled_win);
@@ -113,7 +114,12 @@ MessageSubwindow::create_scrolled_window(GtkWidget* widget_in_window)
 									GTK_POLICY_AUTOMATIC, 
 									GTK_POLICY_AUTOMATIC);
 	
-	gtk_container_add(GTK_CONTAINER(scrolled_win), widget_in_window);
+	
+	if (!viewport)
+		gtk_container_add(GTK_CONTAINER(scrolled_win), widget_in_window);
+	else
+		gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_win),
+			widget_in_window);
 	gtk_widget_show(widget_in_window);
 	
 	GtkWidget* label = create_label();
@@ -878,22 +884,29 @@ gboolean TerminalWindow::term_keypress_cb (GtkWidget *widget,
 		return FALSE;
 	
 	// DEBUG_PRINT ("Terminal key pressed");
-	/* ctrl-c or ctrl-d */
-	if (event->keyval == GDK_c ||
-		event->keyval == GDK_d ||
-		event->keyval == GDK_C ||
+	/* ctrl-d */
+	if (event->keyval == GDK_d ||
 		event->keyval == GDK_D)
 	{
 		/* Ctrl pressed */
 		if (event->state & GDK_CONTROL_MASK)
 		{
-			// DEBUG_PRINT ("Ctrl c/d: Terminal reseting");
+			// DEBUG_PRINT ("Ctrl d: Terminal reseting");
 			kill (tw->m_child_pid, SIGINT);
 			tw->m_child_pid = 0;
 			term_init_cb (GTK_WIDGET (tw->m_terminal), tw);
 			return TRUE;
 		}
 	}
+	/* Shift-Insert */
+	if ((event->keyval == GDK_Insert || event->keyval == GDK_KP_Insert) &&
+		event->state & GDK_SHIFT_MASK)
+	{
+		// DEBUG_PRINT ("Shift-Insert: paste the clipboard contents to the terminal");
+		vte_terminal_paste_clipboard(VTE_TERMINAL(tw->m_terminal));
+		return TRUE;
+	}
+	
 	return FALSE;
 }
 
@@ -970,7 +983,7 @@ WidgetWindow::~WidgetWindow ()
 void
 WidgetWindow::set_widget(GtkWidget* widget)
 {
-	m_scrollbar = create_scrolled_window(widget);
+	m_scrollbar = create_scrolled_window(widget, TRUE);
 }
 
 void
