@@ -65,9 +65,23 @@ void
 on_toolbar_detach_clicked                (GtkButton       *button,
                                         gpointer         user_data);
 
+gboolean
+on_toolbar_find_incremental_start 		(GtkEntry 		*entry, 
+										GdkEvent *e, 
+										gpointer user_data);
+										
+gboolean
+on_toolbar_find_incremental_end 		(GtkEntry *entry,
+										GdkEvent *e, 
+										gpointer user_data);
+										
 void
-on_toolbar_find_clicked                (GtkButton       *button,
-                                        gpointer         user_data);
+on_toolbar_find_incremental 			(GtkEntry *entry, 
+										gpointer user_data);
+										
+void
+on_toolbar_find_clicked 				(GtkButton * button, 
+										gpointer user_data);
 
 void
 on_toolbar_goto_clicked                (GtkButton       *button,
@@ -154,11 +168,13 @@ on_toolbar_step_over_clicked        (GtkButton       *button,
 void
 on_toolbar_toggle_bp_clicked           (GtkButton       *button,
                                         gpointer         user_data);
+/*
 void
 on_toolbar_watch_clicked           (GtkButton       *button,
                                         gpointer         user_data);
+*/
 void
-on_toolbar_stack_clicked           (GtkButton       *button,
+on_toolbar_signals_clicked           (GtkButton       *button,
                                         gpointer         user_data);
 void
 on_toolbar_registers_clicked           (GtkButton       *button,
@@ -237,6 +253,7 @@ void
 on_format_autocomplete_clicked   (GtkButton       *button,
                   gpointer         user_data);
 
+
 #ifdef __cplusplus
 }
 #endif
