@@ -37,6 +37,52 @@
 #include "properties.h"
 #include "resources.h"
 
+#ifdef sun
+int alphasort (const struct dirent **a, const struct dirent **b);
+
+int scandir(const char *dir, struct dirent ***namelist,
+            int (*select)(const struct dirent *),
+            int (*compar)(const struct dirent **, const struct dirent **))
+{
+  DIR *d;
+  struct dirent *entry;
+  register int i=0;
+  size_t entrysize;
+
+  if ((d=opendir(dir)) == NULL)
+     return(-1);
+
+  *namelist=NULL;
+  while ((entry=readdir(d)) != NULL)
+  {
+    if (select == NULL || (select != NULL && (*select)(entry)))
+    {
+      *namelist=(struct dirent **)realloc((void *)(*namelist),
+                 (size_t)((i+1)*sizeof(struct dirent *)));
+	if (*namelist == NULL) return(-1);
+	entrysize=sizeof(struct dirent)-sizeof(entry->d_name)+strlen(entry->d_name)+1;
+	(*namelist)[i]=(struct dirent *)malloc(entrysize);
+	if ((*namelist)[i] == NULL) return(-1);
+	memcpy((*namelist)[i], entry, entrysize);
+	i++;
+    }
+  }
+  if (closedir(d)) return(-1);
+  if (i == 0) return(-1);
+  if (compar != NULL)
+    qsort((void *)(*namelist), (size_t)i, sizeof(struct dirent *), compar);
+    
+  return(i);
+}
+
+
+int alphasort (const struct dirent **a, const struct dirent **b)
+{
+    return (strcmp((*a)->d_name, (*b)->d_name));
+}
+#endif /* sun */
+
+
 const gchar *
 extract_filename (const gchar * full_filename)
 {
@@ -1633,7 +1679,7 @@ GList*
 anjuta_util_parse_args_from_string (const gchar* string)
 {
 	gboolean escaped;
-	gchar    quote;
+	gint8    quote;
 	gchar    buffer[2048];
 	const gchar *s;
 	gint     idx;
@@ -1641,7 +1687,7 @@ anjuta_util_parse_args_from_string (const gchar* string)
 	
 	idx = 0;
 	escaped = FALSE;
-	quote = (gchar)-1;
+	quote = (gint8)-1;
 	s = string;
 	
 	while (*s) {
@@ -1660,14 +1706,14 @@ anjuta_util_parse_args_from_string (const gchar* string)
 			escaped = TRUE;
 		} else if (*s == quote) {
 			/* Current char ends a quotation */
-			quote = (gchar)-1;
+			quote = (gint8)-1;
 			if (!isspace(*(s+1)) && (*(s+1) != '\0')) {
 				/* If there is no space after the quotation or it is not
 				   the end of the string */
 				g_warning ("Parse error while parsing program arguments");
 			}
 		} else if ((*s == '\"' || *s == '\'')) {
-			if (quote == (gchar)-1) {
+			if (quote == (gint8)-1) {
 				/* Current char starts a quotation */
 				quote = *s;
 			} else {
