@@ -15,7 +15,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* Here is the code stored which is shared beetween appwizard and importwizard */
+/* Here is the code stored which is shared between appwizard and importwizard */
+
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 
 #include "wizard_gui.h"
 #include "anjuta.h"
@@ -32,35 +36,27 @@ create_project_start_page (GnomeDruid * druid, gchar * greetings,
 	GdkColor pagestart_title_color = { 0, 65535, 65535, 65535 };
 	GtkWidget *page;
 
-	page = gnome_druid_page_start_new ();
+	page = gnome_druid_page_edge_new (GNOME_EDGE_START);
 	gtk_widget_show (page);
 	gnome_druid_append_page (GNOME_DRUID (druid),
 				 GNOME_DRUID_PAGE (page));
 	gnome_druid_set_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (page));
-	gnome_druid_page_start_set_bg_color (GNOME_DRUID_PAGE_START
-					     (page), &pagestart_bg_color);
-	gnome_druid_page_start_set_logo_bg_color (GNOME_DRUID_PAGE_START
-						  (page),
+	gnome_druid_page_edge_set_bg_color (GNOME_DRUID_PAGE_EDGE (page),
+						  &pagestart_bg_color);
+	gnome_druid_page_edge_set_logo_bg_color (GNOME_DRUID_PAGE_EDGE (page),
 						  &pagestart_logo_bg_color);
-	gnome_druid_page_start_set_textbox_color (GNOME_DRUID_PAGE_START
-						  (page),
+	gnome_druid_page_edge_set_textbox_color (GNOME_DRUID_PAGE_EDGE (page),
 						  &pagestart_textbox_color);
-	gnome_druid_page_start_set_title_color (GNOME_DRUID_PAGE_START
-						(page),
-						&pagestart_title_color);
-	gnome_druid_page_start_set_text (GNOME_DRUID_PAGE_START
-					 (page), greetings);
-	gnome_druid_page_start_set_title (GNOME_DRUID_PAGE_START
-					  (page), title);
-	gnome_druid_page_start_set_logo (GNOME_DRUID_PAGE_START
-					 (page),
-					 anjuta_res_get_image
-					 (ANJUTA_PIXMAP_APPWIZ_LOGO));
-	gnome_druid_page_start_set_watermark (GNOME_DRUID_PAGE_START
-					      (page),
-					      anjuta_res_get_image
+	gnome_druid_page_edge_set_title_color (GNOME_DRUID_PAGE_EDGE (page),
+						  &pagestart_title_color);
+	gnome_druid_page_edge_set_text (GNOME_DRUID_PAGE_EDGE (page),
+						  greetings);
+	gnome_druid_page_edge_set_title (GNOME_DRUID_PAGE_EDGE (page), title);
+	gnome_druid_page_edge_set_logo (GNOME_DRUID_PAGE_EDGE (page),
+					 anjuta_res_get_pixbuf (ANJUTA_PIXMAP_APPWIZ_LOGO));
+	gnome_druid_page_edge_set_watermark (GNOME_DRUID_PAGE_EDGE (page),
+					      anjuta_res_get_pixbuf
 					      (ANJUTA_PIXMAP_APPWIZ_WATERMARK));
-
 	return page;
 }
 
@@ -76,8 +72,9 @@ create_project_type_selection_page (GnomeDruid * druid, GtkWidget ** iconlist)
 	GtkWidget *label2;
 	GtkWidget *druid_vbox1;
 
-	gchar *icon1_file, *icon2_file, *icon3_file, *icon4_file, *icon5_file,
-		*icon6_file, *icon7_file;
+	gchar *icon1_file, *icon8_file, *icon9_file, *icon10_file,
+		*icon11_file, *icon12_file, *icon13_file, *icon14_file, *icon15_file,
+		*icon16_file;
 
 	GdkColor page_bg_color = { 0, 15616, 33280, 46848 };
 	GdkColor page_logo_bg_color = { 0, 15616, 33280, 46848 };
@@ -85,22 +82,22 @@ create_project_type_selection_page (GnomeDruid * druid, GtkWidget ** iconlist)
 
 	GtkWidget *page;
 
-	page = gnome_druid_page_standard_new_with_vals ("", NULL);
+	page = gnome_druid_page_standard_new_with_vals ("", NULL, NULL);
 	gtk_widget_show_all (page);
 	gnome_druid_append_page (GNOME_DRUID (druid),
 				 GNOME_DRUID_PAGE (page));
-	gnome_druid_page_standard_set_bg_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_background (GNOME_DRUID_PAGE_STANDARD
 						(page), &page_bg_color);
-	gnome_druid_page_standard_set_logo_bg_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_logo_background (GNOME_DRUID_PAGE_STANDARD
 						     (page),
 						     &page_logo_bg_color);
-	gnome_druid_page_standard_set_title_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_title_foreground (GNOME_DRUID_PAGE_STANDARD
 						   (page), &page_title_color);
 	gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD
 					     (page), _("Project Type"));
 	gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD
 					    (page),
-					    anjuta_res_get_image
+					    anjuta_res_get_pixbuf
 					    (ANJUTA_PIXMAP_APPWIZ_LOGO));
 
 	frame = gtk_frame_new (NULL);
@@ -137,7 +134,7 @@ create_project_type_selection_page (GnomeDruid * druid, GtkWidget ** iconlist)
 					GTK_POLICY_AUTOMATIC);
 	gtk_container_add (GTK_CONTAINER (frame3), scrolledwindow1);
 
-	iconlist1 = gnome_icon_list_new_flags (110, NULL, 0);
+	iconlist1 = gnome_icon_list_new (110, NULL, 0);
 	gnome_icon_list_set_selection_mode (GNOME_ICON_LIST (iconlist1),
 					    GTK_SELECTION_BROWSE);
 	gtk_widget_show (iconlist1);
@@ -147,48 +144,58 @@ create_project_type_selection_page (GnomeDruid * druid, GtkWidget ** iconlist)
 	gnome_icon_list_set_text_spacing (GNOME_ICON_LIST (iconlist1), 5);
 
 	icon1_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_GENERIC);
-	icon2_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_GTK);
-	icon3_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_GNOME);
-	icon4_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_GTKMM);
-	icon5_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_GNOMEMM);
-	icon6_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_COMPONENT);
-	icon7_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_LIBGLADE);
+	icon8_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_WXWIN);
+	icon9_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_GTK2);
+	icon10_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_GNOME2);
+	icon11_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_COMPONENT);
+	icon12_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_LIBGLADE2);
+	icon13_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_GTKMM2);
+	icon14_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_GNOMEMM2);
+	icon15_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_XWIN);
+	icon16_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_APP_XWINDOCKAPP);
+	
 	if (icon1_file)
 		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
 					icon1_file,
 					_("Generic/Terminal project"));
-
-	if (icon2_file)
+	if (icon9_file)
 		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
-					icon2_file, _("GTK project"));
-
-	if (icon3_file)
+					icon9_file, _("GTK 2.0 project"));
+	if (icon10_file)
 		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
-					icon3_file, _("GNOME project"));
-
-	if (icon4_file)
+					icon10_file, _("GNOME 2.0 project"));
+	if (icon12_file)
 		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
-					icon4_file, _("GTKmm project"));
-
-	if (icon5_file)
+					icon12_file, _("LibGlade 2.0 project"));
+	if (icon13_file)
 		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
-					icon5_file, _("GNOMEmm project"));
-
-	if (icon6_file)
+					icon13_file, _("gtkmm 2.0 project"));
+	if (icon14_file)
 		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
-					icon6_file, _("Bonobo component"));
-
-	if (icon7_file)
+					icon14_file, _("gnomemm 2.0 project"));
+	if (icon11_file)
 		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
-					icon7_file, _("LibGlade project"));
+					icon11_file, _("GNOME 2.0 Bonobo component"));
+	if (icon8_file)
+		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
+					icon8_file, _("wxWindows project"));
+	if (icon15_file)
+		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
+					icon15_file, _("Xlib project"));
+	if (icon16_file)
+		gnome_icon_list_append (GNOME_ICON_LIST (iconlist1),
+					icon16_file, _("X Dock App project"));
 
-	string_free (icon1_file);
-	string_free (icon2_file);
-	string_free (icon3_file);
-	string_free (icon4_file);
-	string_free (icon5_file);
-	string_free (icon6_file);
-	string_free (icon7_file);
+	g_free (icon1_file);
+	g_free (icon8_file);
+	g_free (icon9_file);
+	g_free (icon10_file);
+	g_free (icon11_file);
+	g_free (icon12_file);
+	g_free (icon13_file);
+	g_free (icon14_file);	
+	g_free (icon15_file);	
+	g_free (icon16_file);	
 
 	*iconlist = iconlist1;
 	return page;
@@ -202,7 +209,10 @@ create_project_props_page (GnomeDruid * druid,
 			   GtkWidget ** target,
 			   GtkWidget ** language_c_radio,
 			   GtkWidget ** language_cpp_radio,
-			   GtkWidget ** language_c_cpp_radio)
+			   GtkWidget ** language_c_cpp_radio,
+			   GtkWidget ** target_exec_radio,
+			   GtkWidget ** target_slib_radio,
+			   GtkWidget ** target_dlib_radio)
 {
 	GtkWidget *frame;
 	GtkWidget *vbox3;
@@ -223,27 +233,35 @@ create_project_props_page (GnomeDruid * druid,
 	GtkWidget *radiobutton4;
 	GtkWidget *radiobutton5;
 	GtkWidget *radiobutton6;
-
+	
+	GtkWidget *radiobutton1;
+	GtkWidget *radiobutton2;
+	GtkWidget *radiobutton3;
+	GtkWidget *frame3;
+	GtkWidget *hbox4;
+	GtkWidget *hbox5;
+	GSList *hbox5_group = NULL;
+	
 	GdkColor page_bg_color = { 0, 15616, 33280, 46848 };
 	GdkColor page_logo_bg_color = { 0, 15616, 33280, 46848 };
 	GdkColor page_title_color = { 0, 65535, 65535, 65535 };
 
-	GtkWidget *page = gnome_druid_page_standard_new_with_vals ("", NULL);
+	GtkWidget *page = gnome_druid_page_standard_new_with_vals ("", NULL, NULL);
 	gtk_widget_show_all (page);
 	gnome_druid_append_page (GNOME_DRUID (druid),
 				 GNOME_DRUID_PAGE (page));
-	gnome_druid_page_standard_set_bg_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_background (GNOME_DRUID_PAGE_STANDARD
 						(page), &page_bg_color);
-	gnome_druid_page_standard_set_logo_bg_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_logo_background (GNOME_DRUID_PAGE_STANDARD
 						     (page),
 						     &page_logo_bg_color);
-	gnome_druid_page_standard_set_title_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_title_foreground (GNOME_DRUID_PAGE_STANDARD
 						   (page), &page_title_color);
 	gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD
 					     (page), _("Basic Information"));
 	gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD
 					    (page),
-					    anjuta_res_get_image
+					    anjuta_res_get_pixbuf
 					    (ANJUTA_PIXMAP_APPWIZ_LOGO));
 
 	frame = gtk_frame_new (NULL);
@@ -272,7 +290,7 @@ create_project_props_page (GnomeDruid * druid,
 	gtk_widget_show (hbox2);
 	gtk_box_pack_start (GTK_BOX (vbox3), hbox2, TRUE, TRUE, 0);
 
-	table1 = gtk_table_new (5, 2, FALSE);
+	table1 = gtk_table_new (6, 2, FALSE);
 	gtk_widget_show (table1);
 	gtk_box_pack_start (GTK_BOX (hbox2), table1, TRUE, TRUE, 4);
 	gtk_table_set_row_spacings (GTK_TABLE (table1), 6);
@@ -342,7 +360,7 @@ create_project_props_page (GnomeDruid * druid,
 
 	radiobutton4 = gtk_radio_button_new_with_label (hbox3_group, _("C"));
 	hbox3_group =
-		gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton4));
+		gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton4));
 	gtk_widget_show (radiobutton4);
 	gtk_box_pack_start (GTK_BOX (hbox3), radiobutton4, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (radiobutton4), 5);
@@ -350,7 +368,7 @@ create_project_props_page (GnomeDruid * druid,
 	radiobutton5 =
 		gtk_radio_button_new_with_label (hbox3_group, _("C++"));
 	hbox3_group =
-		gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton5));
+		gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton5));
 	gtk_widget_show (radiobutton5);
 	gtk_box_pack_start (GTK_BOX (hbox3), radiobutton5, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (radiobutton5), 5);
@@ -359,10 +377,45 @@ create_project_props_page (GnomeDruid * druid,
 		gtk_radio_button_new_with_label (hbox3_group,
 						 _("Both C and C++"));
 	hbox3_group =
-		gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton6));
+		gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton6));
 	gtk_widget_show (radiobutton6);
 	gtk_box_pack_start (GTK_BOX (hbox3), radiobutton6, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (radiobutton6), 5);
+	
+	frame3 = gtk_frame_new (_("Target type"));
+	gtk_widget_show (frame3);
+	gtk_table_attach (GTK_TABLE (table1), frame3, 1, 2, 5, 6,
+			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (frame3), 5);
+	
+	hbox4 = gtk_hbox_new (FALSE, 0);
+	gtk_widget_show (hbox4);
+	gtk_container_add (GTK_CONTAINER (frame3), hbox4);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox4), 5);
+	
+	hbox5 = gtk_hbox_new (FALSE, 0);
+	gtk_widget_show (hbox5);
+	gtk_box_pack_start (GTK_BOX (hbox4), hbox5, TRUE, TRUE, 0);
+	
+	radiobutton1 = gtk_radio_button_new_with_label (hbox5_group, _("Executable target"));
+	hbox5_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton1));
+	gtk_widget_show (radiobutton1);
+	gtk_box_pack_start (GTK_BOX (hbox5), radiobutton1, FALSE, FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (radiobutton1), 5);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton1), TRUE);
+	
+	radiobutton2 = gtk_radio_button_new_with_label (hbox5_group, _("Static library target"));
+	hbox5_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton2));
+	gtk_widget_show (radiobutton2);
+	gtk_box_pack_start (GTK_BOX (hbox5), radiobutton2, FALSE, FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (radiobutton2), 5);
+	
+	radiobutton3 = gtk_radio_button_new_with_label (hbox5_group, _("Dynamic library target"));
+	hbox5_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton3));
+	gtk_widget_show (radiobutton3);
+	gtk_box_pack_start (GTK_BOX (hbox5), radiobutton3, FALSE, FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (radiobutton3), 5);
 
 	*prj_name = prj_name_entry;
 	*author = author_entry;
@@ -371,16 +424,24 @@ create_project_props_page (GnomeDruid * druid,
 	*language_c_radio = radiobutton4;
 	*language_cpp_radio = radiobutton5;
 	*language_c_cpp_radio = radiobutton6;
-
+	
+	if (target_exec_radio != NULL)
+	{
+		*target_exec_radio = radiobutton1;
+		*target_slib_radio = radiobutton2;
+		*target_dlib_radio = radiobutton3;
+	}
+	else
+	{
+		gtk_widget_set_sensitive(frame3, FALSE);
+	}
+	
 	return page;
 }
 
 GtkWidget *
 create_project_description_page (GnomeDruid * druid,
-				 GtkWidget ** description,
-				 GtkWidget ** target_exec_radio,
-				 GtkWidget ** target_slib_radio,
-				 GtkWidget ** target_dlib_radio)
+				 GtkWidget ** description)
 {
 	GdkColor page_bg_color = { 0, 15616, 33280, 46848 };
 	GdkColor page_logo_bg_color = { 0, 15616, 33280, 46848 };
@@ -393,26 +454,22 @@ create_project_description_page (GnomeDruid * druid,
 	GtkWidget *scrolledwindow1;
 	GtkWidget *description_text;
 	GtkWidget *druid_vbox3;
-
-	GtkWidget *frame2;
-	GtkWidget *hbox1;
-
-	GtkWidget *page = gnome_druid_page_standard_new_with_vals ("", NULL);
+	GtkWidget *page = gnome_druid_page_standard_new_with_vals ("", NULL, NULL);
 	gtk_widget_show_all (page);
 	gnome_druid_append_page (GNOME_DRUID (druid),
 				 GNOME_DRUID_PAGE (page));
-	gnome_druid_page_standard_set_bg_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_background (GNOME_DRUID_PAGE_STANDARD
 						(page), &page_bg_color);
-	gnome_druid_page_standard_set_logo_bg_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_logo_background (GNOME_DRUID_PAGE_STANDARD
 						     (page),
 						     &page_logo_bg_color);
-	gnome_druid_page_standard_set_title_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_title_foreground (GNOME_DRUID_PAGE_STANDARD
 						   (page), &page_title_color);
 	gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD
 					     (page), _("Project Description"));
 	gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD
 					    (page),
-					    anjuta_res_get_image
+					    anjuta_res_get_pixbuf
 					    (ANJUTA_PIXMAP_APPWIZ_LOGO));
 
 	frame = gtk_frame_new (NULL);
@@ -442,33 +499,14 @@ create_project_description_page (GnomeDruid * druid,
 	gtk_box_pack_start (GTK_BOX (vbox3), scrolledwindow1, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow1), 5);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1),
-					GTK_POLICY_NEVER,
-					GTK_POLICY_AUTOMATIC);
+					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-	description_text = gtk_text_new (NULL, NULL);
+	description_text = gtk_text_view_new ();
 	gtk_widget_show (description_text);
 	gtk_container_add (GTK_CONTAINER (scrolledwindow1), description_text);
-	gtk_text_set_editable (GTK_TEXT (description_text), TRUE);
-
-	frame2 = gtk_frame_new (NULL);
-	/* this would allow the type of target (library, exe, etc) to be specified
-	 * is this really the best page of the druid to do it??
-	 * unimplemented - uncomment the next line to see the GUI */
-	/* gtk_widget_show (frame2); */
-	gtk_box_pack_start (GTK_BOX (vbox3), frame2, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (frame2), 5);
-
-	hbox1 = gtk_hbox_new (FALSE, 0);
-	gtk_widget_show (hbox1);
-	gtk_container_add (GTK_CONTAINER (frame2), hbox1);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox1), 5);
+	//gtk_text_set_editable (GTK_TEXT (description_text), TRUE);
 
 	*description = description_text;
-#if 0				/* Not implemented yet */
-	*target_exec_radio = radiobutton4;
-	*target_slib_radio = radiobutton5;
-	*target_dlib_radio = radiobutton6;
-#endif
 	return page;
 }
 
@@ -488,7 +526,8 @@ create_project_menu_page (GnomeDruid * druid,
 			  GtkWidget ** app_group_combo,
 			  GtkWidget ** term_check,
 			  GtkWidget ** file_header_support,
-			  GtkWidget ** gettext_support_check)
+			  GtkWidget ** gettext_support_check,
+			  GtkWidget ** use_glade_check)
 {
 	GtkWidget *frame;
 	GtkWidget *vbox1;
@@ -498,7 +537,8 @@ create_project_menu_page (GnomeDruid * druid,
 	GtkWidget *frame4;
 	GtkWidget *gpl_checkbutton;
 	GtkWidget *gettext_support_checkbutton;
-
+	GtkWidget *use_glade_checkbutton;
+	
 	GtkWidget *frame1;
 	GtkWidget *table1;
 	GtkWidget *label;
@@ -520,22 +560,22 @@ create_project_menu_page (GnomeDruid * druid,
 	GdkColor page_title_color = { 0, 65535, 65535, 65535 };
 
 
-	GtkWidget *page = gnome_druid_page_standard_new_with_vals ("", NULL);
+	GtkWidget *page = gnome_druid_page_standard_new_with_vals ("", NULL, NULL);
 	gtk_widget_show_all (page);
 	gnome_druid_append_page (GNOME_DRUID (druid),
 				 GNOME_DRUID_PAGE (page));
-	gnome_druid_page_standard_set_bg_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_background (GNOME_DRUID_PAGE_STANDARD
 						(page), &page_bg_color);
-	gnome_druid_page_standard_set_logo_bg_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_logo_background (GNOME_DRUID_PAGE_STANDARD
 						     (page),
 						     &page_logo_bg_color);
-	gnome_druid_page_standard_set_title_color (GNOME_DRUID_PAGE_STANDARD
+	gnome_druid_page_standard_set_title_foreground (GNOME_DRUID_PAGE_STANDARD
 						   (page), &page_title_color);
 	gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD
 					     (page), _("Additional Options"));
 	gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD
 					    (page),
-					    anjuta_res_get_image
+					    anjuta_res_get_pixbuf
 					    (ANJUTA_PIXMAP_APPWIZ_LOGO));
 
 	frame = gtk_frame_new (NULL);
@@ -595,6 +635,14 @@ create_project_menu_page (GnomeDruid * druid,
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 				      (gettext_support_checkbutton), TRUE);
 
+	use_glade_checkbutton =
+		gtk_check_button_new_with_label (_("Generate source code using glade or glademm"));
+	gtk_widget_show (use_glade_checkbutton);
+	gtk_box_pack_start (GTK_BOX (vbox2), use_glade_checkbutton,
+			    TRUE, TRUE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+				      (use_glade_checkbutton), TRUE);
+
 	frame1 = gtk_frame_new (_("GNOME Menu Entry"));
 	gtk_widget_show (frame1);
 	gtk_box_pack_start (GTK_BOX (vbox1), frame1, TRUE, TRUE, 0);
@@ -645,7 +693,7 @@ create_project_menu_page (GnomeDruid * druid,
 			  (GtkAttachOptions) (0), 0, 0);
 
 	combo_entry1 = GTK_COMBO (combo1)->entry;
-	gtk_entry_set_editable (GTK_ENTRY (combo_entry1), FALSE);
+	gtk_editable_set_editable (GTK_EDITABLE (combo_entry1), FALSE);
 
 	list = NULL;
 	i = 0;
@@ -677,6 +725,7 @@ create_project_menu_page (GnomeDruid * druid,
 	*app_group_combo = combo1;
 	*app_group_box = combo_entry1;
 	*term_check = checkbutton1;
+	*use_glade_check = use_glade_checkbutton;
 
 	return page;
 }
@@ -689,31 +738,25 @@ create_project_finish_page (GnomeDruid * druid)
 	GdkColor pagefinish_textbox_color = { 0, 65535, 65535, 65535 };
 	GdkColor pagefinish_title_color = { 0, 65535, 65535, 65535 };
 
-	GtkWidget *page = gnome_druid_page_finish_new ();
+	GtkWidget *page = gnome_druid_page_edge_new (GNOME_EDGE_FINISH);
 	gtk_widget_show (page);
 	gnome_druid_append_page (GNOME_DRUID (druid),
 				 GNOME_DRUID_PAGE (page));
-	gnome_druid_page_finish_set_bg_color (GNOME_DRUID_PAGE_FINISH
-					      (page), &pagefinish_bg_color);
-	gnome_druid_page_finish_set_logo_bg_color (GNOME_DRUID_PAGE_FINISH
-						   (page),
-						   &pagefinish_logo_bg_color);
-	gnome_druid_page_finish_set_textbox_color (GNOME_DRUID_PAGE_FINISH
-						   (page),
-						   &pagefinish_textbox_color);
-	gnome_druid_page_finish_set_title_color (GNOME_DRUID_PAGE_FINISH
-						 (page),
-						 &pagefinish_title_color);
-	gnome_druid_page_finish_set_title (GNOME_DRUID_PAGE_FINISH
-					   (page), _("Summary"));
-	gnome_druid_page_finish_set_logo (GNOME_DRUID_PAGE_FINISH
-					  (page),
-					  anjuta_res_get_image
+	gnome_druid_page_edge_set_bg_color (GNOME_DRUID_PAGE_EDGE(page),
+										&pagefinish_bg_color);
+	gnome_druid_page_edge_set_logo_bg_color (GNOME_DRUID_PAGE_EDGE (page),
+											 &pagefinish_logo_bg_color);
+	gnome_druid_page_edge_set_textbox_color (GNOME_DRUID_PAGE_EDGE (page),
+						   					 &pagefinish_textbox_color);
+	gnome_druid_page_edge_set_title_color (GNOME_DRUID_PAGE_EDGE (page),
+						 				   &pagefinish_title_color);
+	gnome_druid_page_edge_set_title (GNOME_DRUID_PAGE_EDGE (page),
+									 _("Summary"));
+	gnome_druid_page_edge_set_logo (GNOME_DRUID_PAGE_EDGE (page),
+					  anjuta_res_get_pixbuf
 					  (ANJUTA_PIXMAP_APPWIZ_LOGO));
-	gnome_druid_page_finish_set_watermark (GNOME_DRUID_PAGE_FINISH
-					       (page),
-					       anjuta_res_get_image
+	gnome_druid_page_edge_set_watermark (GNOME_DRUID_PAGE_EDGE (page),
+					       anjuta_res_get_pixbuf
 					       (ANJUTA_PIXMAP_APPWIZ_WATERMARK));
-
 	return page;
 }
