@@ -1,5 +1,4 @@
 /*
-*   $Id: get.c,v 1.1 2001/11/22 06:58:33 naba Exp $
 *
 *   Copyright (c) 1996-2001, Darren Hiebert
 *
@@ -306,9 +305,9 @@ static void makeDefineTag (const char *const name, boolean parameterized)
 	e.truncateLine	= TRUE;
 	e.kindName	= "macro";
 	e.kind		= 'd';
-	e.type = TAG_MACRO;
 	if (parameterized)
-		e.extensionFields.arglist = getArglistFromPos(getInputFilePosition(), e.name, TRUE);
+		e.extensionFields.arglist = getArglistFromPos(getInputFilePosition()
+		  , e.name);
 	makeTagEntry (&e);
 	if (parameterized)
 		free((char *) e.extensionFields.arglist);
@@ -624,7 +623,7 @@ process:
 }
 
 
-extern char *getArglistFromPos(fpos_t startPosition, const char *tokenName, boolean isMacro)
+extern char *getArglistFromPos(fpos_t startPosition, const char *tokenName)
 {
 	fpos_t originalPosition;
 	char *result = NULL;
@@ -641,7 +640,7 @@ extern char *getArglistFromPos(fpos_t startPosition, const char *tokenName, bool
 		{
 			fread(result, sizeof(char), pos2 - pos1 + 1, File.fp);
 			result[pos2-pos1+1] = '\0';
-			arglist = getArglistFromStr(result, tokenName, isMacro);
+			arglist = getArglistFromStr(result, tokenName);
 			free(result);
 		}
 	}
@@ -663,6 +662,7 @@ static void stripCodeBuffer(char *buf)
 {
 	int i = 0, pos = 0;
 	ParseState state = st_none_t, prev_state = st_none_t;
+	
 	while (buf[i] != '\0')
 	{
 		switch(buf[i])
@@ -736,7 +736,7 @@ static void stripCodeBuffer(char *buf)
 	return;
 }
 
-extern char *getArglistFromStr(char *buf, const char *name, boolean isMacro)
+extern char *getArglistFromStr(char *buf, const char *name)
 {
 	char *start, *end;
 	int level;
