@@ -45,8 +45,8 @@ extern "C"
 */
 typedef struct _TMWorkspace
 {
-	TMWorkObject work_object;
-	GPtrArray *global_tags;
+	TMWorkObject work_object; /*!< The parent work object */
+	GPtrArray *global_tags; /*!< Global tags loaded at startup */
 	GPtrArray *work_objects; /*!< An array of TMWorkObject pointers */
 } TMWorkspace;
 
@@ -101,8 +101,8 @@ gboolean tm_workspace_load_global_tags(const char *tags_file);
  \param tags_file The file where the tags will be stored.
  \return TRUE on success, FALSE on failure.
 */
-gboolean tm_workspace_create_global_tags(const char *pre_process, const char *includes
-  , const char *tags_file);
+gboolean tm_workspace_create_global_tags(const char *pre_process, const char **includes
+  , int includes_count, const char *tags_file);
 
 /*! Recreates the tag array of the workspace by collecting the tags of
  all member work objects. You shouldn't have to call this directly since
@@ -122,6 +122,9 @@ void tm_workspace_recreate_tags_array(void);
 gboolean tm_workspace_update(TMWorkObject *workspace, gboolean force
   , gboolean recurse, gboolean update_parent);
 
+/*! Dumps the workspace tree - useful for debugging */
+void tm_workspace_dump(void);
+
 /*! Returns all matching tags found in the workspace.
  \param name The name of the tag to find.
  \param type The tag types to return (TMTagType). Can be a bitmask.
@@ -132,6 +135,11 @@ gboolean tm_workspace_update(TMWorkObject *workspace, gboolean force
 const GPtrArray *tm_workspace_find(const char *name, int type, TMTagAttrType *attrs
  , gboolean partial);
 
+/*! Returns a list of parent classes for the given class name
+ \param name Name of the class
+ \return A GPtrArray of TMTag pointers (includes the TMTag for the class) */
+const GPtrArray *tm_workspace_get_parents(const gchar *name);
+
 /*! Frees the workspace structure and all child work objects. Use only when
  exiting from the main program.
 */
