@@ -139,6 +139,31 @@ gboolean tm_workspace_load_global_tags(const char *tags_file)
 	return TRUE;
 }
 
+static guint tm_file_inode_hash(gconstpointer key)
+{
+	struct stat file_stat;
+	const char *filename = (const char*)key;
+	if (stat(filename, &file_stat) == 0)
+	{
+#ifdef TM_DEBUG
+		g_message ("Hash for '%s' is '%d'\n", filename, file_stat.st_ino);
+#endif
+		return g_direct_hash (GUINT_TO_POINTER (file_stat.st_ino));
+	} else {
+		return 0;
+	}
+}
+
+static void tm_move_entries_to_g_list(gpointer key, gpointer value, gpointer user_data)
+{
+	if (user_data == NULL)
+		return;
+
+	GList **pp_list = (GList**)user_data;
+
+	*pp_list = g_list_prepend(*pp_list, value);
+}
+
 gboolean tm_workspace_create_global_tags(const char *pre_process, const char **includes
   , int includes_count, const char *tags_file)
 {
@@ -150,108 +175,101 @@ gboolean tm_workspace_create_global_tags(const char *pre_process, const char **i
 	FILE *fp;
 	TMWorkObject *source_file;
 	GPtrArray *tags_array;
+	GHashTable *includes_files_hash;
 	GList *includes_files = NULL;
-	int list_len;
-	int idx_main;
-	int idx_sub;
-	int remove_count = 0;
-	char *temp_file = g_strdup_printf("%s/%d_%ld_1.cpp", P_tmpdir, getpid(), time(NULL));
-	char *temp_file2 = g_strdup_printf("%s/%d_%ld_2.cpp", P_tmpdir, getpid(), time(NULL));
-	TMTagAttrType sort_attrs[] = { tm_tag_attr_name_t, tm_tag_attr_scope_t
-		, tm_tag_attr_type_t, 0};
+	GList *node;
+	char *temp_file = g_strdup_printf("%s/%d_%ld_1.cpp", P_tmpdir, getpid(),
+									  time(NULL));
+	char *temp_file2 = g_strdup_printf("%s/%d_%ld_2.cpp", P_tmpdir, getpid(),
+									   time(NULL));
+	TMTagAttrType sort_attrs[] = {
+		tm_tag_attr_name_t, tm_tag_attr_scope_t,
+		tm_tag_attr_type_t, 0
+	};
+	
 	if (NULL == (fp = fopen(temp_file, "w")))
 		return FALSE;
 	
 	globbuf.gl_offs = 0;
+	includes_files_hash = g_hash_table_new_full (tm_file_inode_hash,
+												 g_direct_equal,
+												 NULL, g_free);
+
 	for(idx_inc = 0; idx_inc < includes_count; idx_inc++)
 	{
  		int dirty_len = strlen(includes[idx_inc]);
 		char *clean_path = malloc(dirty_len - 1);
 		strncpy(clean_path, includes[idx_inc] + 1, dirty_len - 1);
 		clean_path[dirty_len - 2] = 0;
-
-		//printf("[o][%s]\n", clean_path);
+		
+#ifdef TM_DEBUG
+		g_message ("[o][%s]\n", clean_path);
+#endif
 		glob(clean_path, 0, NULL, &globbuf);
-		//printf("matches: %d\n", globbuf.gl_pathc);
+		
+#ifdef TM_DEBUG
+		g_message ("matches: %d\n", globbuf.gl_pathc);
+#endif
+		
 		for(idx_glob = 0; idx_glob < globbuf.gl_pathc; idx_glob++)
 		{
-			includes_files = g_list_append(includes_files, strdup(globbuf.gl_pathv[idx_glob]));
-			//printf(">>> %s\n", globbuf.gl_pathv[idx_glob]);
+#ifdef TM_DEBUG
+			g_message (">>> %s\n", globbuf.gl_pathv[idx_glob]);
+#endif			
+			if (!g_hash_table_lookup(includes_files_hash,
+									globbuf.gl_pathv[idx_glob]))
+			{
+				char* file_name_copy = strdup(globbuf.gl_pathv[idx_glob]);
+				g_hash_table_insert(includes_files_hash, file_name_copy,
+									file_name_copy);
+#ifdef TM_DEBUG
+				g_message ("Added ...\n");
+#endif
+			}
 		}
 		globfree(&globbuf);
 		free(clean_path);
   	}
 
-
 	/* Checks for duplicate file entries which would case trouble */
+	g_hash_table_foreach(includes_files_hash, tm_move_entries_to_g_list,
+						 &includes_files);
+	
+	includes_files = g_list_reverse (includes_files);
+
+#ifdef TM_DEBUG
+	g_message ("writing out files to %s\n", temp_file);
+#endif
+	node = includes_files;
+	while (node)
 	{
-		struct stat main_stat;
-		struct stat sub_stat;
-
-		remove_count = 0;
-		
-		list_len = g_list_length(includes_files);
-
-		/* We look for files with the same inode */
-		for(idx_main = 0; idx_main < list_len; idx_main++)
-		{
-//			printf("%d / %d\n", idx_main, list_len - 1);
-			stat(g_list_nth_data(includes_files, idx_main), &main_stat);
-			for(idx_sub = idx_main + 1; idx_sub < list_len; idx_sub++)
-			{
-				GList *element = NULL;
-				
-				stat(g_list_nth_data(includes_files, idx_sub), &sub_stat);
-				
-				
-				if(main_stat.st_ino != sub_stat.st_ino)
-					continue;
-			
-				/* Inodes match */
-				
-				element = g_list_nth(includes_files, idx_sub);
-					
-/*				printf("%s == %s\n", g_list_nth_data(includes_files, idx_main), 
-										 g_list_nth_data(includes_files, idx_sub)); */
-					
-				/* We delete the duplicate entry from the list */
-				includes_files = g_list_remove_link(includes_files, element);
-				remove_count++;
-
-				/* Don't forget to free the mallocs (we duplicated every string earlier!) */
-				free(element->data);
-
-				idx_sub--; /* Cause the inner loop not to move; good since we removed 
-							   an element at the current position; we don't have to worry
-							   about the outer loop because the inner loop always starts
-							   after the outer loop's index */
-
-				list_len = g_list_length(includes_files);
-			}
-		}
-	}
-
-
-	printf("writing out files to %s\n", temp_file);
-	for(idx_main = 0; idx_main < g_list_length(includes_files); idx_main++)
-	{
-		char *str = g_strdup_printf("#include \"%s\"\n",
-									(char*)g_list_nth_data(includes_files,
-														   idx_main));
+		char *str = g_strdup_printf("#include \"%s\"\n", (char*)node->data);
 		int str_len = strlen(str);
 
 		fwrite(str, str_len, 1, fp);
-
 		free(str);
-		free(g_list_nth(includes_files, idx_main) -> data);
+		node = g_list_next (node);
 	}
 	
+	g_list_free (includes_files);
+	g_hash_table_destroy(includes_files_hash);
+	includes_files_hash = NULL;
+	includes_files = NULL;
 	fclose(fp);
 
-	command = g_strdup_printf("%s %s >%s", pre_process, temp_file, temp_file2);
+	/* FIXME: The following grep command it be remove the lines 
+	 * G_BEGIN_DECLS and G_END_DECLS from the header files. The reason is
+	 * that in tagmanager, the files are not correctly parsed and the typedefs
+	 * following these lines are incorrectly parsed. The real fix should,
+	 * of course be in tagmanager (c) parser. This is just a temporary fix.
+	 */
+	command = g_strdup_printf("%s %s | grep -v -E '^\\s*(G_BEGIN_DECLS|G_END_DECLS)\\s*$' > %s",
+							  pre_process, temp_file, temp_file2);
+	
 #ifdef TM_DEBUG
 	g_message("Executing: %s", command);
 #endif
+	
 	system(command);
 	g_free(command);
 	unlink(temp_file);
